@@ -1,11 +1,11 @@
 package Sah::Schema::example::array_of_str;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2016-12-09'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 our $schema = [array => {
     summary => 'Array of string',
-    of => ["str", {}, {}],
+    of => ["str", {req=>1}, {}],
 }, {}];
 
 1;
@@ -23,7 +23,11 @@ Sah::Schema::example::array_of_str - Array of string
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::example::array_of_str (from Perl distribution Sah-Schemas-Examples), released on 2016-07-22.
+This document describes version 0.005 of Sah::Schema::example::array_of_str (from Perl distribution Sah-Schemas-Examples), released on 2016-12-09.
+
+=head1 DESCRIPTION
+
+Deprecated, see L<Sah::Schema::aos>.
 
 =head1 HOMEPAGE
 
